==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Snap/SnapAuto/ts/SnapAuto_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>AutoSnap</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Auto Snap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Intersections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>End points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Middle points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Center points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Perpendicular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tangential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Grid points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Points on entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Free positioning</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnapAuto</name>
    <message>
        <location filename="../SnapAutoInit.js" line="+2"/>
        <source>&amp;Auto</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Automatycznie
&amp;Autozoom</translatorcomment>
        <translation type="unfinished">&amp;Automatycznie</translation>
    </message>
    <message>
        <location filename="../SnapAuto.js" line="+34"/>
        <source>Snap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Auto Snap</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Snap/SnapAuto/ts/SnapAuto_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AutoSnap</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Auto Snap</source>
        <translation>Automatyczne przyciąganie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Intersections</source>
        <translation>Przecięcia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>End points</source>
        <translation>Punkty końcowe</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Middle points</source>
        <translation>Punkty środkowe</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Center points</source>
        <translation>Punkty centralne</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Perpendicular</source>
        <translation>Prostopadle</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tangential</source>
        <translation>Stycznie</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference points</source>
        <translation>Punkty odniesienia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Grid points</source>
        <translation>Punkty siatki</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Points on entity</source>
        <translation>Punkty na obiekcie</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Free positioning</source>
        <translation>Swobodne pozycjonowanie</translation>
    </message>
</context>
<context>
    <name>SnapAuto</name>
    <message>
        <location filename="../SnapAutoInit.js" line="+2"/>
        <source>&amp;Auto</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Automatycznie
&amp;Autozoom</translatorcomment>
        <translation>&amp;Automatycznie</translation>
    </message>
    <message>
        <location filename="../SnapAuto.js" line="+34"/>
        <source>Snap</source>
        <translation>Przyciąganie</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Auto Snap</source>
        <translation>Automatyczne przyciąganie</translation>
    </message>
</context>
</TS>
